<?php
/**
 * Template Name: Blog
 */
get_header();

$utouch_the_query = utouch_custom_loop( 'post' );

$utouch_page_title = '' !== get_the_excerpt() ? get_the_excerpt() : get_the_title();
$utouch_layout = utouch_sidebar_conf(false);

$utouch_options = Utouch::options();
$utouch_sort_panel = $utouch_options->get_option('sorting_panel/value', 'yes',Utouch_Options::SOURCE_POST);
$utouch_sort_type = $utouch_options->get_option('sorting_panel/yes/action', 'sort',Utouch_Options::SOURCE_POST);
$utouch_sort_wrapper_class = 'sort' == $utouch_sort_type ? 'sorting-menu' : '';


$utouch_current = absint(
	max(
		1,
		get_query_var( 'paged' ) ? get_query_var( 'paged' ) : get_query_var( 'page' )
	)
);

$utouch_navigation_args = array(
	'total'   => $utouch_the_query->max_num_pages,
	'current' => $utouch_current,
	'prev_text' => '<div class="btn-prev btn--style">
						<svg class="utouch-icon icon-hover utouch-icon-arrow-left-1"><use xlink:href="#utouch-icon-arrow-left-1"></use></svg>
						<svg class="utouch-icon utouch-icon-arrow-left1"><use xlink:href="#utouch-icon-arrow-left1"></use></svg>
					</div>',
	'next_text' => '<div class="btn-next btn--style">
						<svg class="utouch-icon icon-hover utouch-icon-arrow-right-1"><use xlink:href="#utouch-icon-arrow-right-1"></use></svg>
						<svg class="utouch-icon utouch-icon-arrow-right1"><use xlink:href="#utouch-icon-arrow-right1"></use></svg>
					</div>',
);
?>
	<div id="primary" class="container">
		<div class="row">
			<div class="<?php echo esc_attr( $utouch_layout['content-classes'] ) ?>">
				<main id="main" class="site-main">
					<div id="page-content" class="ovh">
						<?php while ( have_posts() ) : the_post();
							the_content();
						endwhile; ?>
					</div>
					<?php if ( $utouch_the_query->have_posts() ) { ?>
						<?php if ( ! empty( $categories ) && 'no' !== $utouch_sort_panel ) : ?>
							<ul class="cat-list align-center <?php echo esc_attr( $utouch_sort_wrapper_class ) ?>">
								<?php if ( 'sort' === $utouch_sort_type ) { ?>
									<li class="cat-list__item active" data-filter="*"><a href="#"
																						 class=""><?php esc_html_e( 'All Projects', 'utouch-lite' ); ?></a>
									</li>
									<?php foreach ( $categories as $utouch_category ) : ?>
										<li class="cat-list__item"
											data-filter=".category_<?php echo esc_attr( $utouch_category->term_id ) ?>"><a
													href="#" class=""><?php echo esc_html( $utouch_category->name ); ?></a>
										</li>
									<?php endforeach; ?>
								<?php } else {
									$utouch_terms = get_terms( $taxonomy, array( 'hide_empty' => true ) );
									foreach ( $utouch_terms as $utouch_term ) : ?>
										<?php $utouch_active = ( $utouch_term->term_id == $term_id ) ? 'active' : ''; ?>
										<li class="cat-list__item <?php echo esc_attr( $utouch_active ) ?>"><a
													href="<?php echo esc_url( get_term_link( $utouch_term->slug, $taxonomy ) ) ?>"><?php echo esc_html( $utouch_term->name ); ?></a>
										</li>
									<?php endforeach; ?>
								<?php } ?>
							</ul>
						<?php endif; ?>
						<div id="blog-loop">
							<?php while ( $utouch_the_query->have_posts() ) : $utouch_the_query->the_post();
								$utouch_format = get_post_format();
								if ( false === $utouch_format ) {
									$utouch_format = 'standard';
								}
								get_template_part( 'post-format/post', $utouch_format );
							endwhile;

							?>
						</div>
						<?php
						echo paginate_links($utouch_navigation_args);
						wp_reset_postdata();
						?>

					<?php } ?>
				</main><!-- #main -->
			</div>
			<?php if ( 'full' !== $utouch_layout['position'] ) { ?>
				<div class="<?php echo esc_attr( $utouch_layout['sidebar-classes'] ) ?>">
					<?php get_sidebar(); ?>
				</div>
			<?php } ?>
		</div><!-- #row -->
	</div><!-- #primary -->

<?php


get_footer();