<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link    https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Utouch
 */
// Options Variables

$color_scheme       = $header_style = $custom_menu = $header_absolute = $header_animation = $sticky_atts = $sticky_pinned = $sticky_unpinned = $sticky_header_on_mobile = $website_preloader = '';
$header_class       = array();
$header_class[]     = 'header';
$page_id            = get_the_ID();
$show_top_bar       = 'hide';
$show_sticky_header = 'yes';
$decorative_line    = 'show';
$is_boxed           = 'no';

if ( function_exists( 'fw_get_db_customizer_option' ) ) {
	$show_top_bar            = fw_get_db_customizer_option( 'sections-top-bar/status', 'hide' );
	$show_sticky_header      = fw_get_db_customizer_option( 'sticky_header/value', 'yes' );
	$decorative_line         = fw_get_db_customizer_option( 'decorative-line', 'show' );
	$header_text_color       = fw_get_db_customizer_option( 'header-text-color', '' );
	$sticky_header_on_mobile = fw_get_db_customizer_option( 'sticky_header/yes/on_mobile', false );
	$preloader               = fw_get_db_customizer_option( 'website_preloader', array() );
	$website_preloader       = utouch_akg( 'show', $preloader, 'no' );
	$website_preloader_color = utouch_akg( 'yes/color', $preloader, '#66b5ff' );
	$boxed                   = fw_get_db_customizer_option( 'boxed_container', array() );
	$is_boxed                = utouch_akg( 'show', $boxed, 'no' );
}

if ( is_singular() && function_exists( 'fw_get_db_post_option' ) ) {
	// Header options
	$enable_customization = fw_get_db_post_option( $page_id, 'custom-header/enable', 'no' );
	if ( 'yes' === $enable_customization ) {
		$custom_header_opt = fw_get_db_post_option( $page_id, 'custom-header/yes', array() );
		$show_top_bar      = utouch_akg( 'sections-top-bar/status', $custom_header_opt, 'hide' );
		$decorative_line   = utouch_akg( 'decorative-line', $custom_header_opt, 'show' );
		$header_text_color = utouch_akg( 'header-text-color', $custom_header_opt, '' );

		Utouch::set_var( 'header_page_bg_color', utouch_akg( 'header_bg_color', $custom_header_opt, '' ) );
	}
}

if ( ! empty( $header_text_color ) ) {
	$header_class[] = 'header-color-inherit';
}

if ( ! empty( $color_scheme ) ) {
	$header_class[] = $color_scheme;
}

if ( $show_sticky_header === 'no' ) {
	$header_class[] = 'header-absolute';
	$header_class[] = 'disable-sticky';
} else {
	$header_class[] = 'header-sticky-desktop';
}

if ( true === $sticky_header_on_mobile ) {
	$header_class[] = 'header-sticky-mobile';
}

if ( 'show' === $show_top_bar ) {
	$header_class[] = 'header-top-bar';
	$header_class[] = 'header-has-topbar';
}
?>
    <!DOCTYPE html>
<html <?php language_attributes(); ?>>
    <head>
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<?php wp_head(); ?>
    </head>
<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
    <a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e( 'Skip to content', 'utouch-lite' ); ?></a>
<?php
if ( 'yes' === $website_preloader ) {
	$preloader_bg = UTOUCH_THEME_URI . '/svg/preload.svg';
	echo utouch_html_tag( 'div', array(
		'id'    => 'hellopreloader',
		'style' => 'display: block; position: fixed;z-index: 99999;top: 0;left: 0;width: 100%;height: 100%;min-width: 100%;background: ' . $website_preloader_color . ' url(' . esc_url( $preloader_bg ) . ') center center no-repeat;background-size: 41px;opacity: 1;'
	), true );
}
if ( $is_boxed === 'yes' ) { ?>
<div class="boxed-wrapper">
<?php }
if ( 'landing-template.php' !== get_page_template_slug() ) { ?>
    <!-- Header -->
    <header class="<?php echo esc_attr( implode( ' ', $header_class ) ); ?>" id="site-header">
        <div class="header-wrapper">
            <div class="container">
				<?php if ( $show_top_bar ) { ?>
                    <div id="top-bar-js" class="top-bar-link">
                        <svg class="utouch-icon utouch-icon-arrow-top">
                            <use xlink:href="#utouch-icon-arrow-top"></use>
                        </svg>
                    </div>
				<?php } ?>

                <div class="header-content-wrapper">

                    <a href="<?php echo esc_url( home_url( '' ) ) ?>" class="site-logo">
						<?php utouch_logo(); ?>
                    </a>

					<div class="utouch-header-menu-wrapper">
						<?php
						wp_nav_menu( array(
							'theme_location' => 'header-menu',
							'menu_id'        => 'header-menu',
							'menu_class'     => 'utouch-header-menu',
							'container'      => 'ul',
						) );
						?>
						<div class="mobile-menu" x-data="{mobileMenuOpen: false}">
							<button class="mobile-menu-button btn--transparent"
									@click="mobileMenuOpen = true
                    $nextTick(() => $refs.modalCloseButton.focus())"
							>
								<svg class="crumina-icon" width="20" height="10">
									<path fill-rule="evenodd" d="M19 2H1c-.345 0-1-.655-1-1s.655-1 1-1h18c.345 0 1 .655 1 1s-.655 1-1 1zM1 4h18c.345 0 1 .655 1 1 0 .977-.655 1-1 1H1c-.345 0-1-.019-1-1 0-.988.655-1 1-1zm6 4h12c.345 0 1 .655 1 1s-.655 1-1 1H7c-.345 0-1-.655-1-1s.655-1 1-1z" />
								</svg>
							</button>

							<div class="mobile-menu-popup"
								 x-cloak
								 x-show="mobileMenuOpen"
								 @click.away="mobileMenuOpen = false"
								 x-transition:enter="transition ease-out duration-500"
								 x-transition:enter-start="opacity-0 transform translate-y-full"
								 x-transition:enter-end="opacity-100 transform translate-y-0"
								 x-transition:leave="transition ease-in duration-500"
								 x-transition:leave-start="opacity-100 transform translate-y-full"
								 x-transition:leave-end="opacity-0 transform translate-y-0"
							>

								<div class="mobile-menu-popup-wrap">

									<div class="mobile-menu-logo-close-wrap">
										<a href="<?php echo esc_url( home_url( '' ) ) ?>" class="site-logo">
											<?php utouch_logo(); ?>
										</a>
										<button class="hook-tabindex-js hide" x-on:focus="$refs.modalCloseButton.focus()"></button>
										<button class="hook-tabindex-js hide" x-on:focus="$refs.menuLastItem.focus()"></button>
										<button class="mobile-menu-close btn--transparent"
												@click="mobileMenuOpen = false"
												x-ref="modalCloseButton"

										>
											<svg class="crumina-icon" width="20" height="20">
												<path fill-rule="evenodd" d="M11.763 9.995l7.862-7.87a1.251 1.251 0 0 0-1.768-1.77l-7.862 7.87L2.132.355a1.249 1.249 0 0 0-1.768 0 1.253 1.253 0 0 0 0 1.77l7.863 7.87-7.863 7.87a1.253 1.253 0 0 0 .884 2.137c.32 0 .64-.123.884-.367l7.863-7.87 7.862 7.87a1.247 1.247 0 0 0 1.768 0 1.251 1.251 0 0 0 0-1.77l-7.862-7.87z"></path>
											</svg>
										</button>
									</div>

									<?php
									wp_nav_menu( array(
										'theme_location' => 'header-menu-mobile',
										'menu_id'        => 'header-menu-mobile',
										'menu_class'     => 'utouch-header-menu header-menu--mobile',
										'container'      => 'ul',
									) );
									?>

								</div>


							</div>
							<button class="hook-tabindex-js hide"
									x-on:focus="$refs.modalCloseButton.focus()"
							></button>
						</div>
					</div>
					<?php utouch_additional_nav(); ?>

                </div>
            </div>
	        <?php
	        if ( 'show' === $show_top_bar ) {
		        get_template_part( 'parts/section', 'topbar' );
	        }
	        ?>
	        <?php if ( 'show' === $decorative_line ): ?>
				<div class="header-lines-decoration">
					<span class="bg-secondary-color"></span>
					<span class="bg-blue"></span>
					<span class="bg-blue-light"></span>
					<span class="bg-orange-light"></span>
					<span class="bg-red"></span>
					<span class="bg-green"></span>
					<span class="bg-secondary-color"></span>
				</div>
	        <?php endif; ?>
        </div>
    </header>
	<?php
	if ( $header_absolute !== true ) {
		echo '<div id="header-spacer" class="header-spacer"></div>';
	}

	$search_color = function_exists( 'fw_get_db_customizer_option' ) ? fw_get_db_customizer_option( 'search-icon/yes/color-scheme', 'search--white' ) : 'search--white';
	?>
    <div class="search-popup <?php echo esc_attr( $search_color ) ?>" x-data="">
		<button class="hook-tabindex-js hide" x-on:focus="$refs.modalSearchButton.focus()"></button>
        <button class="popup-close js-popup-close cd-nav-trigger" x-ref="modalSearchCloseButton">
            <svg class="utouch-icon utouch-icon-cancel-1">
                <use xlink:href="#utouch-icon-cancel-1"></use>
            </svg>
        </button>
        <div class="search-full-screen">
            <div class="search-standard">
                <form id="search-header" method="get" action="<?php echo esc_url( home_url( '/' ) ); ?>"
                      class="search-inline" name="form-search-header">
					<a href="#" class="close js-popup-clear-input form-icon" aria-expanded="false">
						<svg class="utouch-icon utouch-icon-cancel-1"><use xlink:href="#utouch-icon-cancel-1"></use></svg>
					</a>
                    <input class="search-input" name="s" value="<?php get_search_query(); ?>"
                           placeholder="<?php echo esc_attr__( 'What are you looking for?', 'utouch-lite' ) ?>"
                           autocomplete="off" type="search">
                    <button type="submit" class="form-icon" x-ref="modalSearchButton">
                        <svg class="utouch-icon utouch-icon-search">
                            <use xlink:href="#utouch-icon-search"></use>
                        </svg>
                    </button>
                </form>
				<button class="hook-tabindex-js hide" x-on:focus="$refs.modalSearchCloseButton.focus()"></button>
            </div>
        </div>
    </div>

    <div class="cd-overlay-nav">
        <span></span>
    </div> <!-- cd-overlay-nav -->

    <div class="cd-overlay-content">
        <span></span>
    </div>
    <!-- ... End Header -->
<?php } ?>
    <div class="content-wrapper">
<?php
if ( Utouch::template_stunning()->show && ! is_404() ) {
	get_template_part( 'parts/stunning/style' );
}