<?php

if ( !defined( 'ABSPATH' ) ) {
    die( 'Direct access forbidden.' );
}

/**
 * Settings and options for online preview Customizer changes.
 *
 * @package Utouch
 */
function utouch_customizer_swap_sections( $wp_customize ) {

    $panel_design = $wp_customize->get_section('panel_design');
    
    if(!$panel_design){
        return;
    }
    
    $controls = $wp_customize->controls();
    
    foreach ( $controls as $control ) {
        if( in_array( $control->section, array('colors', 'background_image') )){
            $control->section = 'panel_design';
        }
        
        if($control->id === 'background_color'){
            $control->priority = 2.5;
        }
        
        if($control->id === 'background_image'){
            $control->priority = 2.4;
        }
        
        if($control->id === 'boxed_container'){
            $control->priority = 2.3;
        }
        
        if($control->id === 'website_preloader'){
            $control->priority = 2.2;
        }
    }
}

add_action( 'customize_register', 'utouch_customizer_swap_sections', 99999 );

if ( defined( 'FW' ) ) {

    function utouch_register_partial_refresh_stunning( $wp_customize, $setting_name,
                                                        $fallback_refresh = false ) {
        $wp_customize->get_setting( $setting_name )->transport = 'postMessage';
        $wp_customize->selective_refresh->add_partial( $setting_name, array(
            'selector'            => '#stunning-section',
            'container_inclusive' => true,
            'render_callback'     => 'utouch_stunning_header_partial_template',
            'fallback_refresh'    => $fallback_refresh,
        ) );
    }

    function utouch_register_partial_refresh_header( $wp_customize, $setting_name,
                                                      $fallback_refresh = false ) {
        $wp_customize->get_setting( $setting_name )->transport = 'postMessage';
        $wp_customize->selective_refresh->add_partial( $setting_name, array(
            'selector'            => '#site-header',
            'container_inclusive' => true,
            'render_callback'     => 'utouch_header_partial_template',
            'fallback_refresh'    => $fallback_refresh,
        ) );
    }

    function utouch_register_partial_refresh_footer( $wp_customize, $setting_name,
                                                      $fallback_refresh = false ) {
        $wp_customize->get_setting( $setting_name )->transport = 'postMessage';
        $wp_customize->selective_refresh->add_partial( $setting_name, array(
            'selector'            => '#site-footer',
            'container_inclusive' => true,
            'render_callback'     => 'utouch_footer_partial_template',
            'fallback_refresh'    => $fallback_refresh,
        ) );
    }

    /**
     * @param WP_Customize_Manager $wp_customize
     * @internal
     */
    function utouch_action_customizer_live_fw_options( $wp_customize ) {
        // Header
        //header design
        $wp_customize->get_setting( 'fw_options[logo-title]' )->transport        = 'postMessage';
        $wp_customize->get_setting( 'fw_options[logo-subtitle]' )->transport     = 'postMessage';
        $wp_customize->get_setting( 'fw_options[header_bg_color]' )->transport   = 'postMessage';
        $wp_customize->get_setting( 'fw_options[header-text-color]' )->transport = 'postMessage';
        //stunning header

        $wp_customize->get_setting( 'fw_options[stunning_text_color]' )->transport = 'postMessage';

        $wp_customize->get_setting( 'fw_options[stunning_background_color]' )->transport = 'postMessage';
		$wp_customize->get_setting('fw_options[stunning_overlay_color]')->transport = 'postMessage';
        //footer
        $wp_customize->get_setting( 'fw_options[footer_text_color]' )->transport         = 'postMessage';
        $wp_customize->get_setting( 'fw_options[footer_title_color]' )->transport        = 'postMessage';

        $wp_customize->get_setting( 'fw_options[footer_bg_image]' )->transport = 'postMessage';
        $wp_customize->get_setting( 'fw_options[footer_bg_cover]' )->transport = 'postMessage';
        $wp_customize->get_setting( 'fw_options[footer_bg_color]' )->transport = 'postMessage';

        $wp_customize->get_setting( 'fw_options[footer_copyright]' )->transport     = 'postMessage';
        $wp_customize->get_setting( 'fw_options[copyright_bg_color]' )->transport   = 'postMessage';
        $wp_customize->get_setting( 'fw_options[copyright_text_color]' )->transport = 'postMessage';



        //selective refresh
        if ( isset( $wp_customize->selective_refresh ) ) {
            //stunning
            utouch_register_partial_refresh_stunning( $wp_customize, 'fw_options[stunning-show]', true );
            utouch_register_partial_refresh_stunning( $wp_customize, 'fw_options[stunning_bg_options]', false );
            utouch_register_partial_refresh_stunning( $wp_customize, 'fw_options[stunning_overlay_color]', false );

            utouch_register_partial_refresh_stunning( $wp_customize, 'fw_options[stunning_title]', false );
            utouch_register_partial_refresh_stunning( $wp_customize, 'fw_options[stunning_category]', false );
            utouch_register_partial_refresh_stunning( $wp_customize, 'fw_options[stunning_breadcrumbs]', false );
            utouch_register_partial_refresh_stunning( $wp_customize, 'fw_options[stunning_author]', false );
            utouch_register_partial_refresh_stunning( $wp_customize, 'fw_options[stunning_additional]', false );

            //header
            //utouch_register_partial_refresh_header( $wp_customize, 'fw_options[sticky_header]', false );
            utouch_register_partial_refresh_header( $wp_customize, 'fw_options[logo-image]', false );
            utouch_register_partial_refresh_header( $wp_customize, 'fw_options[logo-retina]', false );
            utouch_register_partial_refresh_header( $wp_customize, 'fw_options[search-icon]', false );

            //footer
            utouch_register_partial_refresh_footer( $wp_customize, 'fw_options[site-description]', false );
            utouch_register_partial_refresh_footer( $wp_customize, 'fw_options[scroll_top_icon]', false );
        }

        add_action( 'customize_preview_init', 'utouch_action_customizer_live_fw_options_preview' );
    }

    add_action( 'customize_register', 'utouch_action_customizer_live_fw_options' );

    /**
     * @internal
     */
    function utouch_action_customizer_live_fw_options_preview() {
        $translation_array = array( 'templateUrl' => UTOUCH_THEME_URI );
        wp_enqueue_script(
        'utouch-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'jquery', 'customize-preview' ), fw()->theme->manifest->get_version(), true
        );
        wp_localize_script( 'utouch-customizer', 'theme_vars', $translation_array );
    }

}
