<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct access forbidden.' );
}
/**
 * Helper functions and classes with static methods for usage in theme
 */

/**
 * Callback function will be displayed if main menu is empty.
 *
 */
function utouch_menu_fallback() {

	$output = '<ul class="utouch-header-menu"><li><div class="no-menu-box">';
	// Translators 1: Link to Menus, 2: Link to Customize
	$output .= sprintf( esc_attr__( 'Please assign a menu to the primary menu location under %1$s or %2$s the design.', 'utouch-lite' ), sprintf( wp_kses( __( '<a href="%s">Menus</a>', 'utouch-lite' ), array( 'a' => array( 'href' => array() ) ) ), get_admin_url( get_current_blog_id(), 'nav-menus.php' )
	), sprintf( wp_kses( __( '<a href="%s">Customize</a>', 'utouch-lite' ), array( 'a' => array( 'href' => array() ) ) ), get_admin_url( get_current_blog_id(), 'customize.php' )
		)
	);
	$output .= '</div></li></ul>';

	utouch_render( $output );
}

/**
 * Register Lato Google font.
 *
 * @return string
 */
function utouch_font_url() {
	if ( function_exists( 'fw_get_db_customizer_option' ) ) {
		$font_families = array();
		$tags          = array( 'body', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'nav', 'logo' );
		foreach ( $tags as $single_tag ) {
			$font_options = fw_get_db_customizer_option( 'typography_' . $single_tag, array() );
			if ( true === utouch_akg( 'google_font', $font_options, false ) ) {
				$font_families[] = $font_options['family'] . ':' . $font_options['variation'] . '&subset=latin,' . $font_options['subset'] . '';
			}
		}
	}
	$font_families[]     = 'Nunito:300,400,700,900';
	$custom_google_fonts = implode( '|', $font_families );
	if ( 'Nunito:300,400,700,900' == $custom_google_fonts ) {
		$font_url = UTOUCH_THEME_URI . '/css/nunito-font.css';
	} else {
		$font_url = esc_url( add_query_arg( 'family', urlencode( $custom_google_fonts ), "//fonts.googleapis.com/css" ) );
		$font_url = str_replace( '%2B', '+', $font_url );
	}


	return $font_url;
}

if ( ! function_exists( 'utouch_backgrounds' ) ):

	/**
	 * Return List of backgrounds patterns.
	 *
	 * @return array
	 */
	function utouch_backgrounds() {
		$background_image['none'] = array(
			'icon' => UTOUCH_THEME_URI . '/images/thumb/bg-0.png',
			'css'  => array(
				'background-image' => 'none'
			),
		);
		for ( $i = 1; $i < 22; $i ++ ) {
			$background_image[ 'bg-' . $i . '' ] = array(
				'icon' => UTOUCH_THEME_URI . '/images/thumb/bg-' . $i . '.png',
				'css'  => array(
					'background-image' => 'url("' . UTOUCH_THEME_URI . '/images/thumb/bg-' . $i . '.png' . '")'
				),
			);
		}

		return $background_image;
	}

endif;


if ( ! function_exists( 'utouch_get_menus' ) ) :

	/**
	 * Get array with menus for theme options
	 *
	 * @return array
	 */
	function utouch_get_menus() {
		$menus_list = array( '' => esc_html__( 'Default', 'utouch-lite' ) );
		$menus      = get_terms( 'nav_menu', array( 'hide_empty' => true ) );
		if ( is_array( $menus ) ) {
			foreach ( $menus as $menu_instance ) {
				$menus_list[ $menu_instance->term_id ] = $menu_instance->name;
			}
		}

		return $menus_list;
	}

endif;


if ( ! function_exists( 'utouch_sidebar_conf' ) ) {

	/**
	 * Return classes for content / sidebar positions.
	 *
	 * @return array
	 */
	function utouch_sidebar_conf( $is_page = false ) {

		$sidebar_width_classes = 'col-lg-3 col-md-4 col-sm-12';
		$content_width_classes = 'col-lg-12 col-md-12 col-sm-12';
		$current_position      = 'full';


		if ( function_exists( 'fw_ext_sidebars_get_current_position' ) ) {
			$current_position = fw_ext_sidebars_get_current_position();
			if ( 'right' === $current_position ) {
				$content_width_classes = 'col-lg-8 col-md-12 col-sm-12';
				$sidebar_width_classes = 'col-lg-4 col-md-12 col-sm-12';
			} elseif ( 'left' === $current_position ) {
				$content_width_classes = ' col-lg-push-4 col-lg-8 col-md-12 col-sm-12';
				$sidebar_width_classes = ' col-lg-pull-8 col-lg-4 col-md-12 col-sm-12';
			} elseif ( null === $current_position && ( is_home() || is_category() || is_singular( 'post' ) || is_search() ) ) {
				$content_width_classes = 'col-lg-8 col-md-12 col-sm-12';
				$sidebar_width_classes = 'col-lg-4 col-md-12 col-sm-12';
				$current_position      = 'right';
			} else {
				$current_position = 'full';
			}
		} elseif ( ! $is_page ) {
			$content_width_classes = 'col-lg-8 col-md-12 col-sm-12';
			$sidebar_width_classes = 'col-lg-4 col-md-12 col-sm-12';
			$current_position      = 'right';
		}

		return array(
			'content-classes' => $content_width_classes,
			'sidebar-classes' => $sidebar_width_classes,
			'position'        => $current_position
		);
	}

}

if ( ! function_exists( 'utouch_gen_link_for_shortcode' ) ) :

	/**
	 * Generate link from block options
	 *
	 * @param array $atts Shortcode options
	 *
	 * @return array
	 */
	function utouch_gen_link_for_shortcode( $atts ) {
		$link_source = utouch_akg( 'link/selected/selected', $atts, '' );
		if ( 'page' === $link_source ) {
			$link = get_permalink( utouch_akg( 'link/selected/page/link/0', $atts, '' ) );
		} else {
			$link = utouch_akg( 'link/selected/url/link', $atts, '' );
		}
		$target = utouch_akg( 'link/target', $atts, '_self' );

		$url['link']   = $link;
		$url['target'] = $target;

		return $url;
	}

endif;


if ( ! function_exists( 'utouch_social_network_icons()' ) ) :

	/**
	 * List of social networks names with file names for options;
	 *
	 * @return array
	 */
	function utouch_social_network_icons() {
		$networks = array(
			'amazon.svg'          => 'Amazon',
			'app-store.svg'       => 'App Store',
			'behance.svg'         => 'Behance',
			'bing.svg'            => 'Bing',
			'creative-market.svg' => 'Creative Market',
			'deviantart.svg'      => 'Deviantart',
			'dribbble.svg'        => 'Dribbble',
			'dropbox.svg'         => 'Dropbox',
			'envato.svg'          => 'Envato',
			'facebook.svg'        => 'Facebook',
			'flickr.svg'          => 'Flickr',
			'google-play.svg'     => 'Google Play',
			'instagram.svg'       => 'Instagram',
			'kickstarter.svg'     => 'Kickstarter',
			'linkedin.svg'        => 'Linkedin',
			'medium.svg'          => 'Medium',
			'periscope.svg'       => 'Periscope',
			'pinterest.svg'       => 'Pinterest',
			'quora.svg'           => 'Quora',
			'reddit.svg'          => 'Reddit',
			'shutterstock.svg'    => 'Shutterstock',
			'skype.svg'           => 'Skype',
			'slack.svg'           => 'Slack',
			'snapchat.svg'        => 'Snapchat',
			'soundcloud.svg'      => 'Soundcloud',
			'spotify.svg'         => 'Spotify',
			'trello.svg'          => 'Trello',
			'telegram.svg'        => 'Telegram',
			'tumblr.svg'          => 'Tumblr',
			'twitter.svg'         => 'Twitter',
			'vimeo.svg'           => 'Vimeo',
			'vk.svg'              => 'VK.com',
			'whatsapp.svg'        => 'Whatsapp',
			'wikipedia.svg'       => 'Wikipedia',
			'wordpress.svg'       => 'WordPress',
			'youtube.svg'         => 'Youtube',
		);

		return $networks;
	}

endif;


if ( ! function_exists( 'utouch_button_colors' ) ) :

	/**
	 * List of button color variations for options;
	 *
	 * @return array
	 */
	function utouch_button_colors() {
		$colors = array(
			'primary'      => esc_html__( 'Primary color', 'utouch-lite' ),
			'secondary'    => esc_html__( 'Secondary color', 'utouch-lite' ),
			'white'        => esc_html__( 'White', 'utouch-lite' ),
			'dark'         => esc_html__( 'Dark', 'utouch-lite' ),
			'black'        => esc_html__( 'Black', 'utouch-lite' ),
			'grey'         => esc_html__( 'Gray', 'utouch-lite' ),
			'dark-gray'    => esc_html__( 'Dark gray', 'utouch-lite' ),
			'grey-light'   => esc_html__( 'Gray light', 'utouch-lite' ),
			'blue'         => esc_html__( 'Blue', 'utouch-lite' ),
			'dark-blue'    => esc_html__( 'Dark blue', 'utouch-lite' ),
			'purple'       => esc_html__( 'Purple', 'utouch-lite' ),
			'breez'        => esc_html__( 'Breez', 'utouch-lite' ),
			'orange'       => esc_html__( 'Orange', 'utouch-lite' ),
			'orange-light' => esc_html__( 'Orange light', 'utouch-lite' ),
			'yellow'       => esc_html__( 'Yellow', 'utouch-lite' ),
			'green'        => esc_html__( 'Green', 'utouch-lite' ),
			'light-green'  => esc_html__( 'Green light', 'utouch-lite' ),
			'brown'        => esc_html__( 'Brown', 'utouch-lite' ),
			'red'          => esc_html__( 'Red', 'utouch-lite' ),
			'rose'         => esc_html__( 'Rose', 'utouch-lite' ),
			'violet'       => esc_html__( 'Violet', 'utouch-lite' ),
			'olive'        => esc_html__( 'Olive', 'utouch-lite' ),
			'lime'         => esc_html__( 'Lime', 'utouch-lite' ),
			'transparent'  => esc_html__( 'Transparent', 'utouch-lite' ),
		);

		return $colors;
	}

endif;


if ( ! function_exists( 'utouch_get_svg_icon' ) ) {

	/**
	 * Insert into page svg icons as inline elements.
	 *
	 * @param $svg_url string Path to svg file
	 *
	 * @return bool|string
	 */
	function utouch_get_svg_icon( $svg_url ) {

		$svg_file_new = '';
		$find_string  = '<svg';

		$svg_file      = wp_remote_get( esc_url_raw( $svg_url ) );
		$response_code = wp_remote_retrieve_response_code( $svg_file );
		if ( 200 === $response_code ) {
			$svg_file = wp_remote_retrieve_body( $svg_file );
			// Remove dimensions
			$svg_file = preg_replace( "/(width|height)=\".*?\"/", "", $svg_file );
			// Add class "utouch-icon"
			if ( false === strpos( $svg_file, 'utouch-icon' ) ) {
				$svg_file = str_replace( $find_string, $find_string . ' class="utouch-icon" ', $svg_file );
			}
			$position     = strpos( $svg_file, $find_string );
			$svg_file_new = substr( $svg_file, $position );
		} else {
			$svg_file_new = '<span class="svg-replace utouch-icon" data-src="' . esc_url( $svg_url ) . '"></span>';
		}

		return $svg_file_new;
	}

}


//Convert col decimal format to class
function utouch_column_width_class( $width ) {

	if ( empty( $width ) ) {
		return 'col-md-12 col-sm-12';
	}

	if ( strpos( $width, '%' ) !== false ) {
		$width = (float) $width;
		if ( $width < 12 ) {
			return 'col-md-1 col-sm-6 col-xs-12';
		} else if ( $width < 18 ) {
			return 'col-md-2 col-sm-6 col-xs-12';
		} else if ( $width < 22.5 ) {
			return 'kc_col-of-5';
		} else if ( $width < 29.5 ) {
			return 'col-md-3 col-sm-6 col-xs-12';
		} else if ( $width < 37 ) {
			return 'col-md-4 col-sm-12';
		} else if ( $width < 46 ) {
			return 'col-md-5 col-sm-12';
		} else if ( $width < 54.5 ) {
			return 'col-md-6 col-sm-12';
		} else if ( $width < 63 ) {
			return 'col-md-7 col-sm-12';
		} else if ( $width < 71.5 ) {
			return 'col-md-8 col-sm-12';
		} else if ( $width < 79.5 ) {
			return 'col-md-9 col-sm-12';
		} else if ( $width < 87.5 ) {
			return 'col-md-10 col-sm-12';
		} else if ( $width < 95.5 ) {
			return 'col-md-11 col-sm-12';
		} else {
			return 'col-md-12 col-sm-12';
		}
	}

	$matches     = explode( '/', $width );
	$width_class = '';
	$n           = 12;
	$m           = 12;

	if ( isset( $matches[0] ) && ! empty( $matches[0] ) ) {
		$n = $matches[0];
	}
	if ( isset( $matches[1] ) && ! empty( $matches[1] ) ) {
		$m = $matches[1];
	}

	if ( $n == 2.4 ) {
		$width_class = 'kc_col-of-5';
	} else {
		if ( $n > 0 && $m > 0 ) {
			$value = ceil( ( $n / $m ) * 12 );
			if ( $value > 0 && $value <= 12 ) {
				$width_class = 'col-md-' . $value;
			}
		}
	}

	return $width_class;
}

function utouch_stunning_header_partial_template() {
	if ( ! Utouch::template_stunning()->show ) {
		return '';
	}
	ob_start();
	get_template_part( 'parts/stunning/style' );
	$html = ob_get_clean();
	$css  = utouch_html_tag( 'style', array(), Utouch::template_stunning()->get_css() );
	$html = substr_replace( $html, $css, '', 0 );

	$html = str_replace( '<!--inline-css-->', $css, $html );

	return $html;
}

function utouch_header_partial_template() {
	$color_scheme       = $header_style = $custom_menu = $header_absolute = $sticky_atts = $sticky_pinned = $sticky_unpinned = '';
	$header_class       = array();
	$header_class[]     = 'header';
	$page_id            = get_the_ID();
	$show_top_bar       = 'hide';
	$show_sticky_header = 'yes';
	$decorative_line    = 'show';


	if ( function_exists( 'fw_get_db_customizer_option' ) ) {
		$show_top_bar       = fw_get_db_customizer_option( 'sections-top-bar/status', 'hide' );
		$show_sticky_header = fw_get_db_customizer_option( 'sticky_header/value', 'yes' );
		$decorative_line    = fw_get_db_customizer_option( 'decorative-line', 'show' );
		$header_text_color  = fw_get_db_customizer_option( 'header-text-color', '' );
	}
	if ( is_singular() && function_exists( 'fw_get_db_post_option' ) ) {
		// Header options
		$enable_customization = fw_get_db_post_option( $page_id, 'custom-header/enable', 'no' );
		if ( 'yes' === $enable_customization ) {
			$custom_header_opt = fw_get_db_post_option( $page_id, 'custom-header/yes', array() );
			$show_top_bar      = utouch_akg( 'sections-top-bar/status', $custom_header_opt, 'hide' );
			$decorative_line   = utouch_akg( 'decorative-line', $custom_header_opt, 'show' );
			$header_text_color = utouch_akg( 'header-text-color', $custom_header_opt, '' );

			Utouch::set_var( 'header_page_bg_color', utouch_akg( 'header_bg_color', $custom_header_opt, '' ) );
		}
	}

	if ( ! empty( $header_text_color ) ) {
		$header_class[] = 'header-color-inherit';
	}

	if ( ! empty( $color_scheme ) ) {
		$header_class[] = $color_scheme;
	}

	if ( $show_sticky_header === 'no' ) {
		$header_class[] = 'header-absolute';
		$header_class[] = 'disable-sticky';
	}

	if ( 'show' === $show_top_bar ) {
		$header_class[] = 'header-top-bar';
		$header_class[] = 'header-has-topbar';
	}
	ob_start();
	?>
    <header class="<?php echo esc_attr( implode( ' ', $header_class ) ); ?>" id="site-header">

        <div class="container">
			<?php if ( $show_top_bar ) { ?>
                <div id="top-bar-js" class="top-bar-link">
                    <svg class="utouch-icon utouch-icon-arrow-top">
                        <use xlink:href="#utouch-icon-arrow-top"></use>
                    </svg>
                </div>
			<?php } ?>

			<div class="header-content-wrapper">

				<a href="<?php echo esc_url( home_url( '' ) ) ?>" class="site-logo">
			        <?php utouch_logo(); ?>
				</a>

				<div class="utouch-header-menu-wrapper">
			        <?php
			        wp_nav_menu( array(
				        'theme_location' => 'header-menu',
				        'menu_id'        => 'header-menu',
				        'menu_class'     => 'utouch-header-menu',
				        'container'      => 'ul',
			        ) );
			        ?>
					<div class="mobile-menu" x-data="{mobileMenuOpen: false}">
						<button class="mobile-menu-button btn--transparent"
								@click="mobileMenuOpen = true
                    $nextTick(() => $refs.modalCloseButton.focus())"
						>
							<svg class="crumina-icon" width="20" height="10">
								<path fill-rule="evenodd" d="M19 2H1c-.345 0-1-.655-1-1s.655-1 1-1h18c.345 0 1 .655 1 1s-.655 1-1 1zM1 4h18c.345 0 1 .655 1 1 0 .977-.655 1-1 1H1c-.345 0-1-.019-1-1 0-.988.655-1 1-1zm6 4h12c.345 0 1 .655 1 1s-.655 1-1 1H7c-.345 0-1-.655-1-1s.655-1 1-1z" />
							</svg>
						</button>

						<div class="mobile-menu-popup"
							 x-cloak
							 x-show="mobileMenuOpen"
							 @click.away="mobileMenuOpen = false"
							 x-transition:enter="transition ease-out duration-500"
							 x-transition:enter-start="opacity-0 transform translate-y-full"
							 x-transition:enter-end="opacity-100 transform translate-y-0"
							 x-transition:leave="transition ease-in duration-500"
							 x-transition:leave-start="opacity-100 transform translate-y-full"
							 x-transition:leave-end="opacity-0 transform translate-y-0"
						>

							<div class="mobile-menu-popup-wrap">

								<div class="mobile-menu-logo-close-wrap">
									<a href="<?php echo esc_url( home_url( '' ) ) ?>" class="site-logo">
								        <?php utouch_logo(); ?>
									</a>
									<button class="hook-tabindex-js hide" x-on:focus="$refs.modalCloseButton.focus()"></button>
									<button class="hook-tabindex-js hide" x-on:focus="$refs.menuLastItem.focus()"></button>
									<button class="mobile-menu-close btn--transparent"
											@click="mobileMenuOpen = false"
											x-ref="modalCloseButton"

									>
										<svg class="crumina-icon" width="20" height="20">
											<path fill-rule="evenodd" d="M11.763 9.995l7.862-7.87a1.251 1.251 0 0 0-1.768-1.77l-7.862 7.87L2.132.355a1.249 1.249 0 0 0-1.768 0 1.253 1.253 0 0 0 0 1.77l7.863 7.87-7.863 7.87a1.253 1.253 0 0 0 .884 2.137c.32 0 .64-.123.884-.367l7.863-7.87 7.862 7.87a1.247 1.247 0 0 0 1.768 0 1.251 1.251 0 0 0 0-1.77l-7.862-7.87z"></path>
										</svg>
									</button>
								</div>

						        <?php
						        wp_nav_menu( array(
							        'theme_location' => 'header-menu-mobile',
							        'menu_id'        => 'header-menu-mobile',
							        'menu_class'     => 'utouch-header-menu header-menu--mobile',
							        'container'      => 'ul',
						        ) );
						        ?>

							</div>


						</div>
						<button class="hook-tabindex-js hide"
								x-on:focus="$refs.modalCloseButton.focus()"
						></button>
					</div>
				</div>
		        <?php utouch_additional_nav(); ?>

			</div>
        </div>

	    <?php
	    if ( 'show' === $show_top_bar ) {
		    get_template_part( 'parts/section', 'topbar' );
	    }
	    ?>
	    <?php if ( 'show' === $decorative_line ): ?>
			<div class="header-lines-decoration">
				<span class="bg-secondary-color"></span>
				<span class="bg-blue"></span>
				<span class="bg-blue-light"></span>
				<span class="bg-orange-light"></span>
				<span class="bg-red"></span>
				<span class="bg-green"></span>
				<span class="bg-secondary-color"></span>
			</div>
	    <?php endif; ?>
    </header>
	<?php
	if ( true !== $header_absolute ) {
		echo '<div id="header-spacer" class="header-spacer"></div>';
	}
	?>

	<?php
	$search_color = function_exists( 'fw_get_db_customizer_option' ) ? fw_get_db_customizer_option( 'search-icon/yes/color-scheme', 'search--white' ) : 'search--white';
	?>
	<div class="search-popup <?php echo esc_attr( $search_color ) ?>" x-data="">
		<button class="hook-tabindex-js hide" x-on:focus="$refs.modalSearchButton.focus()"></button>
		<button class="popup-close js-popup-close cd-nav-trigger" x-ref="modalSearchCloseButton">
			<svg class="utouch-icon utouch-icon-cancel-1">
				<use xlink:href="#utouch-icon-cancel-1"></use>
			</svg>
		</button>
		<div class="search-full-screen">
			<div class="search-standard">
				<form id="search-header" method="get" action="<?php echo esc_url( home_url( '/' ) ); ?>"
					  class="search-inline" name="form-search-header">
					<a href="#" class="close js-popup-clear-input form-icon" aria-expanded="false">
						<svg class="utouch-icon utouch-icon-cancel-1"><use xlink:href="#utouch-icon-cancel-1"></use></svg>
					</a>
					<input class="search-input" name="s" value="<?php get_search_query(); ?>"
						   placeholder="<?php echo esc_attr__( 'What are you looking for?', 'utouch-lite' ) ?>"
						   autocomplete="off" type="search">
					<button type="submit" class="form-icon" x-ref="modalSearchButton">
						<svg class="utouch-icon utouch-icon-search">
							<use xlink:href="#utouch-icon-search"></use>
						</svg>
					</button>
				</form>
				<button class="hook-tabindex-js hide" x-on:focus="$refs.modalSearchCloseButton.focus()"></button>
			</div>
		</div>
	</div>
	<?php
	$html = ob_get_clean();

	$custom_css = '';

	if ( null === $header_bg_color = Utouch::get_var( 'header_page_bg_color' ) ) {
		$header_bg_color = fw_get_db_customizer_option( 'header_bg_color', '' );
	}
	if ( ! empty( $header_bg_color ) ) {
		$custom_css .= '#site-header{ background:' . esc_attr( $header_bg_color ) . ' }';
	}

	$header_text_color = fw_get_db_customizer_option( 'header-text-color', '' );
	if ( is_singular() && function_exists( 'fw_get_db_post_option' ) ) {
		// Header options
		if ( 'yes' === fw_get_db_post_option( get_the_ID(), 'custom-header/enable', 'no' ) ) {
			$header_text_color = fw_get_db_post_option( get_the_ID(), 'custom-header/yes/header-text-color', '#fff' );
		}
	}
	if ( ! empty( $header_text_color ) ) {
		$custom_css .= '#site-header{ color:' . esc_attr( $header_text_color ) . ' }';
		$custom_css .= '#site-header{ fill:' . esc_attr( $header_text_color ) . ' }';
		$custom_css .= '#site-header{ border-color:' . esc_attr( $header_text_color ) . ' }';
	}
	$html .= utouch_html_tag( 'style', array( 'id' => 'header-customize-css' ), $custom_css );

	return $html;
}

function utouch_footer_partial_template() {


	$copyright_class = $footer_contacts = $description_enable = $description_title = $description_text = $description_columns = $description_class = $description_socials = $footer_fixed = $footer_text = '';

	global $allowedtags;
	$my_theme = wp_get_theme();

	$show_to_top = 'yes';
	$fixed_totop = false;

	$footer_copyright = '<span>Copyright &copy; '. date('Y') .'<a href="' . esc_html( $my_theme->get( 'ThemeURI' ) ) . '">' . esc_html( $my_theme->get( 'Name' ) ) . ' WordPress theme</a></span>';

	if ( function_exists( 'fw_get_db_customizer_option' ) ) {


		$footer_fixed = fw_get_db_customizer_option( 'footer_fixed', false );
		$footer_text  = fw_get_db_customizer_option( 'footer_text_color', '' );
		$footer_title = fw_get_db_customizer_option( 'footer_title_color', '' );

		$site_description    = fw_get_db_customizer_option( 'site-description', '' );
		$description_enable  = utouch_akg( 'value', $site_description, 'no' );
		$description_title   = utouch_akg( 'yes/description/title', $site_description, '' );
		$description_text    = utouch_akg( 'yes/description/desc', $site_description, '' );
		$description_columns = utouch_akg( 'yes/width-columns', $site_description, '7' );
		$description_socials = utouch_akg( 'yes/social-networks', $site_description, array() );

		$footer_copyright = fw_get_db_customizer_option( 'footer_copyright', '' );
		$copyright_class  = fw_get_db_customizer_option( 'size_copyright_section', 'large' );

		$copyright_text = fw_get_db_customizer_option( 'copyright_text_color', '' );

		$scroll_option = fw_get_db_customizer_option( 'scroll_top_icon', array() );
		$show_to_top   = utouch_akg( 'value', $scroll_option, 'yes' );
		$fixed_totop   = utouch_akg( 'yes/fixed', $scroll_option, false );
	}
	$footer_class = true === $footer_fixed ? 'js-fixed-footer' : '';
	if ( ! empty( $footer_text ) || ! empty( $footer_title ) ) {
		$footer_class .= ' font-color-custom';
	}
	if ( ! empty( $copyright_text ) ) {
		$copyright_class .= ' font-color-custom';
	}

	$scroll_button_class = true === $fixed_totop ? 'back-to-top-fixed' : '';
	$desc_columns_class  = 'col-lg-' . $description_columns . ' col-md-' . $description_columns . ' col-sm-12 col-xs-12';

	if ( 'yes' === $description_enable ) {
		$column = intval( 11 - $description_columns );
		$offset = '1';
		if ( $column < 2 ) {
			$column = 12;
			$offset = '0';
		}
		$sidebar_columns = 'col-lg-offset-' . $offset . ' col-lg-' . $column . ' col-md-' . ( $column + 1 ) . ' col-sm-12 col-xs-12';
	} else {
		$sidebar_columns = 'col-lg-12 col-md-12 col-sm-12 col-xs-12 info';
	}


	if ( ( 'yes' !== $description_enable || ( empty( $description_title ) && empty( $description_text ) ) ) && ! is_active_sidebar( 'sidebar-footer' ) ) {
		$footer_class .= ' footer-empty ';
	}

	ob_start();
	?>
    <footer class="footer  <?php echo esc_attr( $footer_class ) ?>" id="site-footer">
        <div class="footer-wrapper">
            <div class="header-lines-decoration">
                <span class="bg-secondary-color"></span>
                <span class="bg-blue"></span>
                <span class="bg-blue-light"></span>
                <span class="bg-orange-light"></span>
                <span class="bg-red"></span>
                <span class="bg-green"></span>
                <span class="bg-secondary-color"></span>
            </div>

            <div class="container">
                <div class="row">
					<?php
					if ( 'yes' === $description_enable &&
					     ( ! empty( $description_title ) || ! empty( $description_text ) ) ||
					     ( ! empty( $description_socials ) && is_array( $description_socials ) )
					) {
						?>
                        <div class="<?php echo esc_attr( $desc_columns_class ) ?>">
							<?php if ( ! empty( $description_title ) || ! empty( $description_text ) ) { ?>
                                <div class="widget w-info">
									<?php if ( ! empty( $description_title ) ) { ?>
                                        <h5 class="widget-title"><?php echo esc_html( $description_title ) ?></h5>
                                        <div class="heading-line">
                                            <span class="short-line"></span>
                                            <span class="long-line"></span>
                                        </div>
										<?php
									}
									if ( ! empty( $description_text ) ) {
										?>
                                        <div class="heading-text">
											<?php utouch_render( $description_text ) ?>
                                        </div>
									<?php } ?>
                                </div>
							<?php } ?>
                        </div>

					<?php } ?>

					<?php
					if ( is_active_sidebar( 'sidebar-footer' ) ) {
						?>
                        <div class="<?php echo esc_attr( $sidebar_columns ); ?>">
                            <div class="row">
								<?php
								ob_start();
								dynamic_sidebar( 'sidebar-footer' );
								$output                 = ob_get_clean();
								$footer_sibebar_columns = utouch_get_widget_columns( 'sidebar-footer' );
								$footer_sibebar_columns = 'col-lg-' . $footer_sibebar_columns . ' col-md-' . $footer_sibebar_columns . ' col-sm-12 col-xs-12';
								echo str_replace( 'columns_class_replace', $footer_sibebar_columns, $output );
								?>
                            </div>
                        </div>
					<?php } ?>
                </div>

            </div>

            <div class="sub-footer">
				<?php if ( 'yes' === $show_to_top ) { ?>

                    <a class="back-to-top <?php echo esc_attr( $scroll_button_class ); ?>" href="#">
                        <svg class="utouch-icon utouch-icon-arrow-top">
                            <use xlink:href="#utouch-icon-arrow-top"></use>
                        </svg>
                    </a>
				<?php } ?>

				<?php if ( ! empty( $footer_copyright ) ) { ?>

                    <div class="container  <?php echo esc_attr( $copyright_class ) ?>">
                        <div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                                <span class="site-copyright-text">
                                    <?php echo wp_kses( $footer_copyright, $allowedtags ) ?>
                                </span>
                            </div>
                        </div>
                    </div>
				<?php } ?>


            </div>

        </div>

    </footer>

	<?php get_template_part( 'parts/contact', 'form' ) ?>

	<?php
	$html = ob_get_clean();
	if ( function_exists( 'fw_get_db_customizer_option' ) ) {
		$footer_bg       = fw_get_db_customizer_option( 'footer_bg_color', '' );
		$footer_bg_img   = fw_get_db_customizer_option( 'footer_bg_image', '' );
		$footer_bg_cover = fw_get_db_customizer_option( 'footer_bg_cover', false );
		$footer_text     = fw_get_db_customizer_option( 'footer_text_color', '' );
		$footer_title    = fw_get_db_customizer_option( 'footer_title_color', '' );
	}

	$custom_css = '';
	if ( ! empty( $footer_bg ) || ! empty( $footer_bg_img ) || ! empty( $footer_text ) ) {
		$custom_css .= '#site-footer{';
		if ( ! empty( $footer_bg ) ) {
			$custom_css .= 'background-color:' . esc_attr( $footer_bg ) . ';';
		}
		if ( ! empty( $footer_bg_img ) ) {
			$bg_img_url = utouch_akg( 'data/css/background-image', $footer_bg_img, '' );
			if ( isset( $footer_bg_img ) && ! empty( $footer_bg_img ) ) {
				$custom_css .= 'background-image:' . ( $bg_img_url ) . ';';

				if ( true === $footer_bg_cover ) {
					$custom_css .= 'background-size:cover;';
				}
			}
		}
		if ( ! empty( $footer_text ) ) {
			$custom_css .= 'color:' . esc_attr( $footer_text ) . ';';
		}
		$custom_css .= '}';
	}
	if ( ! empty( $footer_title ) ) {
		$custom_css .= '#site-footer .widget .widget-title, #site-footer > .container a:not(.btn), #site-footer .social__item svg, #site-footer .w-list ul.list, #site-footer .widget_nav_menu ul.list{';
		$custom_css .= 'color:' . esc_attr( $footer_title ) . ';';
		$custom_css .= 'fill:' . esc_attr( $footer_title ) . ';';
		$custom_css .= '}';
	}

	// Copyright section styling.
	if ( function_exists( 'fw_get_db_customizer_option' ) ) {
		$copyright_bg   = fw_get_db_customizer_option( 'copyright_bg_color', '' );
		$copyright_text = fw_get_db_customizer_option( 'copyright_text_color', '' );
	}
	if ( ! empty( $copyright_bg ) || ! empty( $copyright_text ) ) {
		if ( ! empty( $copyright_bg ) ) {
			$custom_css .= '#site-footer .sub-footer{ background-color:' . esc_attr( $copyright_bg ) . '}';
		}
		if ( ! empty( $copyright_text ) ) {
			$custom_css .= '#site-footer .site-copyright-text{ color:' . esc_attr( $copyright_text ) . '}';
		}
	}

	$html .= utouch_html_tag( 'style', array( 'id' => 'footer-customize-css' ), $custom_css );

	return $html;
}

function utouch_is_phone( $phone ) {
	preg_match( '/^(\(?\+?[0-9]*\)?)?[0-9_\- \(\)]*$/', $phone, $output_array );

	return ! empty( $output_array );
}

function utouch_is_email( $email ) {
	preg_match( '/^(?!(?:(?:\x22?\x5C[\x00-\x7E]\x22?)|(?:\x22?[^\x5C\x22]\x22?)){255,})(?!(?:(?:\x22?\x5C[\x00-\x7E]\x22?)|(?:\x22?[^\x5C\x22]\x22?)){65,}@)(?:(?:[\x21\x23-\x27\x2A\x2B\x2D\x2F-\x39\x3D\x3F\x5E-\x7E]+)|(?:\x22(?:[\x01-\x08\x0B\x0C\x0E-\x1F\x21\x23-\x5B\x5D-\x7F]|(?:\x5C[\x00-\x7F]))*\x22))(?:\.(?:(?:[\x21\x23-\x27\x2A\x2B\x2D\x2F-\x39\x3D\x3F\x5E-\x7E]+)|(?:\x22(?:[\x01-\x08\x0B\x0C\x0E-\x1F\x21\x23-\x5B\x5D-\x7F]|(?:\x5C[\x00-\x7F]))*\x22)))*@(?:(?:(?!.*[^.]{64,})(?:(?:(?:xn--)?[a-z0-9]+(?:-[a-z0-9]+)*\.){1,126}){1,}(?:(?:[a-z][a-z0-9]*)|(?:(?:xn--)[a-z0-9]+))(?:-[a-z0-9]+)*)|(?:\[(?:(?:IPv6:(?:(?:[a-f0-9]{1,4}(?::[a-f0-9]{1,4}){7})|(?:(?!(?:.*[a-f0-9][:\]]){7,})(?:[a-f0-9]{1,4}(?::[a-f0-9]{1,4}){0,5})?::(?:[a-f0-9]{1,4}(?::[a-f0-9]{1,4}){0,5})?)))|(?:(?:IPv6:(?:(?:[a-f0-9]{1,4}(?::[a-f0-9]{1,4}){5}:)|(?:(?!(?:.*[a-f0-9]:){5,})(?:[a-f0-9]{1,4}(?::[a-f0-9]{1,4}){0,3})?::(?:[a-f0-9]{1,4}(?::[a-f0-9]{1,4}){0,3}:)?)))?(?:(?:25[0-5])|(?:2[0-4][0-9])|(?:1[0-9]{2})|(?:[1-9]?[0-9]))(?:\.(?:(?:25[0-5])|(?:2[0-4][0-9])|(?:1[0-9]{2})|(?:[1-9]?[0-9]))){3}))\]))$/', $email, $output_array );

	return ! empty( $output_array );
}

function utouch_custom_loop( $post_type = '', $post_id = 0, $terms = 0, $page = 0 ) {
	$sticky_posts = get_option( 'sticky_posts' );
	$post_id      = $post_id ? $post_id : get_the_ID();

		$per_page = get_option( 'posts_per_page' );
		$order    = 'DESC';
		$orderby  = 'date';
		$taxonomy = 'category';


	if ( function_exists( 'fw_get_db_post_option' ) ) {
		$meta_per_page = fw_get_db_post_option( $post_id, 'per_page' );
		$meta_order    = fw_get_db_post_option( $post_id, 'order' );
		$meta_orderby  = fw_get_db_post_option( $post_id, 'orderby' );
		$meta_terms    = fw_get_db_post_option( $post_id, 'taxonomy_select' );
		$meta_exclude  = fw_get_db_post_option( $post_id, 'exclude' );
	}

	if ( isset( $meta_per_page ) && ! empty( $meta_per_page ) ) {
		$per_page = $meta_per_page;
	}

	if ( isset( $meta_order ) && ! empty( $meta_order ) && ! ( 'default' === $meta_order ) ) {
		$order = $meta_order;
	}

	if ( isset( $meta_orderby ) && ! empty( $meta_orderby ) && ! ( 'default' === $meta_orderby ) ) {
		$orderby = $meta_orderby;
	}

	if ( is_front_page() ) {
		$paged = ( get_query_var( 'page' ) ) ? get_query_var( 'page' ) : 1;
	} else {
		$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
	}

	if ( $terms ) {
		$meta_terms   = array( $terms );
		$meta_exclude = false;
	}

	if ( $page ) {
		$paged = $page;
	}

	$args = array(
		'post_type'      => $post_type,
		'paged'          => $paged,
		'posts_per_page' => $per_page,
		'order'          => $order,
		'orderby'        => $orderby,
	);

	if ( ! empty( $meta_terms ) ) {
		if ( true === $meta_exclude ) {
			$operator = 'NOT IN';
		} else {
			$operator = 'IN';
		}
		$args['tax_query'] = array(
			array(
				'taxonomy' => $taxonomy,
				'field'    => 'term_id',
				'terms'    => $meta_terms,
				'operator' => $operator,
			),
		);
	}

	$utouch_query = new WP_Query( $args );

	wp_reset_postdata();

	return $utouch_query;
}

/**
 * Echo data
 */
function utouch_render() {
	foreach ( func_get_args() as $arg ) {
		echo "{$arg}";
	}
}