<?php

if ( !defined( 'ABSPATH' ) ) {
    die( 'Direct access forbidden.' );
}
//custom styles
add_action( 'wp_enqueue_scripts', 'utouch_custom_css_styles', 99 );

//custom styles
add_action( 'wp_enqueue_scripts', '_utouch_custom_font', 99 );

function _utouch_generate_font_styles( $tag ) {
    $font        = fw_get_db_customizer_option( 'typography_' . $tag, array() );
    $font_family = utouch_akg( 'family', $font, 'Default' );
    $font_color  = utouch_akg( 'color', $font, '' );

    if ( $tag === 'logo' ) {
        $font_css = '.site-logo .logo-title{';
    } else if ( $tag === 'nav' ) {
        $font_css = '.utouch-header-menu *, .utouch-header-menu > li > a{';
    } else if ( $tag === 'body' ) {
        $font_css = 'body, article p{';
    } else {
        $font_css = $tag . ', .' . $tag . '{';
    }
    if ( !empty( $font_family ) && 'Default' !== $font_family ) {
        $font_css .= 'font-family:"' . $font_family . '", sans-serif;';
        $variant  = utouch_akg( 'variation', $font, '' );
        if ( $variant ) {
            if ( substr_count( $variant, 'italic' ) > 0 ) {
                $font_css .= 'font-style:italic;';
                $variant  = str_replace( 'italic', '', $variant );
            }
            $font_css .= 'font-weight:' . $variant . ';';
        } elseif ( false === $font[ 'google_font' ] ) {
            $font_css .= 'font-style:' . $font[ 'style' ] . ';';
            $font_css .= 'font-weight:' . $font[ 'weight' ] . ';';
        }
    }

    if ( !empty( $font_color ) ) {
        $font_css .= 'color:' . $font_color . ';';
    }

    $letter_spacing = utouch_akg( 'letter-spacing', $font, '' );
    if ( !empty( $letter_spacing ) ) {
        $font_css .= 'letter-spacing:' . $letter_spacing . 'px;';
    }
    $size = utouch_akg( 'size', $font, '' );
    if ( !empty( $size ) ) {
        $font_css .= 'font-size:' . $size . 'px;';
    }
    $font_css .= '} ';

    return $font_css;
}

function _utouch_custom_font() {
    $custom_css = '';

    if ( function_exists( 'fw_get_db_settings_option' ) ) {
        $custom_css .= _utouch_generate_font_styles( 'body' );
        $custom_css .= _utouch_generate_font_styles( 'nav' );
        $custom_css .= _utouch_generate_font_styles( 'logo' );
        $custom_css .= _utouch_generate_font_styles( 'h1' );
        $custom_css .= _utouch_generate_font_styles( 'h2' );
        $custom_css .= _utouch_generate_font_styles( 'h3' );
        $custom_css .= _utouch_generate_font_styles( 'h4' );
        $custom_css .= _utouch_generate_font_styles( 'h5' );
        $custom_css .= _utouch_generate_font_styles( 'h6' );
    }
    wp_add_inline_style( 'utouch-theme-style', $custom_css );
}

function utouch_custom_css_styles() {
    if ( function_exists( 'fw_get_db_customizer_option' ) ) {
        $custom_css      = '';
        $primary_color   = fw_get_db_customizer_option( 'primary_color', '#0083ff' );
        $secondary_color = fw_get_db_customizer_option( 'secondary_color', '#9db5d4' );

	    if ( ! empty( $primary_color ) && '#0083ff' !== $primary_color ) {

		    $custom_css .= '
			:root {
				--primary-accent-color: ' . esc_attr( $primary_color ) . ';
			}';
	    }

        if ( !empty( $secondary_color ) && '#9db5d4' !== $secondary_color ) {

	        $custom_css .= '
			:root {
				--secondary-accent-color: ' . esc_attr( $secondary_color ) . ';
			}';
        }

        $menu_bg_color  = '';
        $padding_top    = 120;
        $padding_bottom = 120;
        if ( function_exists( 'fw_get_db_customizer_option' ) ) {
            $menu_bg_color           = fw_get_db_customizer_option( 'dropdown-style/2/bg-color', '#ecf4fc' );
            $sections_padding_data   = fw_get_db_customizer_option( 'sections_padding', '' );
            $sections_padding_picker = utouch_akg( 'sections_padding_picker', $sections_padding_data, 'medium' );

            switch ( $sections_padding_picker ) {
                case 'small':
                    $padding_top    = 70;
                    $padding_bottom = 70;
                    break;
                case 'medium':
                    $padding_top    = 120;
                    $padding_bottom = 120;
                    break;
                case 'large':
                    $padding_top    = 170;
                    $padding_bottom = 170;
                    break;
                default:
                    $padding_top    = (int) utouch_akg( 'custom/top', $sections_padding_data, 120 );
                    $padding_bottom = (int) utouch_akg( 'custom/bottom', $sections_padding_data, 120 );
                    break;
            }
        }

        if ( is_singular() && function_exists( 'fw_get_db_post_option' ) ) {
            // Header options
            $enable_customization = fw_get_db_post_option( get_the_ID(), 'custom-header/enable', 'no' );
            if ( 'yes' === $enable_customization ) {
                $menu_bg_color = fw_get_db_post_option( get_the_ID(), 'custom-header/yes/dropdown-style/2/bg-color', '#ecf4fc' );
            }
        }

        if ( !empty( $menu_bg_color ) ) {
            $custom_css .= '.utouch .header--menu-rounded .utouch-header-menu > li > a:hover {
			background-color: ' . $menu_bg_color . ';}';
        }

        if ( is_int( $padding_top ) && is_int( $padding_bottom ) ) {
            $custom_css .= ".kc_row:not(.kc_row_inner) {padding: {$padding_top}px 0 {$padding_bottom}px;}";
        }

        // Boxing style
        $boxed       = fw_get_db_customizer_option( 'boxed_container', array() );
        $is_boxed    = utouch_akg( 'show', $boxed, 'no' );
        $boxed_width = (int) utouch_akg( 'yes/width', $boxed, 1200 );

        if ( $is_boxed === 'yes' && $boxed_width ) {
            $custom_css .= '.boxed-wrapper, .header-wrapper, .footer-wrapper { width:' . esc_attr( $boxed_width ) . 'px; max-width: 100%; margin: 0 auto; }';
        }

        // Header
        if ( null === $header_bg_color = Utouch::get_var( 'header_page_bg_color' ) ) {
            $header_bg_color = fw_get_db_customizer_option( 'header_bg_color', '' );
        }
        if ( !empty( $header_bg_color ) ) {
            $custom_css .= '#site-header .header-wrapper{ background:' . esc_attr( $header_bg_color ) . ' }';
        }

        $header_text_color = fw_get_db_customizer_option( 'header-text-color', '' );
        if ( is_singular() && function_exists( 'fw_get_db_post_option' ) ) {
            // Header options
            if ( 'yes' === fw_get_db_post_option( get_the_ID(), 'custom-header/enable', 'no' ) ) {
                $header_text_color = fw_get_db_post_option( get_the_ID(), 'custom-header/yes/header-text-color', '#fff' );
            }
        }
        if ( !empty( $header_text_color ) ) {
            $custom_css .= '#site-header{ color:' . esc_attr( $header_text_color ) . ' }';
            $custom_css .= '#site-header{ fill:' . esc_attr( $header_text_color ) . ' }';
            $custom_css .= '#site-header{ border-color:' . esc_attr( $header_text_color ) . ' }';
        }

        $options = fw_get_db_customizer_option( 'stunning-show', array() );


        $style                = '';
        $bg_color             = fw_get_db_customizer_option( 'stunning_background_color', '' );
        $bg_image             = fw_get_db_customizer_option( 'stunning_bg_image', array() );
        $bg_cover             = fw_get_db_customizer_option( 'stunning_bg_cover', false );
        $text_color           = fw_get_db_customizer_option( 'stunning_text_color', '' );
        $enable_customization = fw_get_db_post_option( get_the_ID(), 'custom-stunning/enable', 'no' );



        if ( is_category() ) {
            $enable_customization = fw_get_db_term_option( get_queried_object_id(), 'category', 'custom-stunning/enable', 'no' );
        }
        //stunning header
        $custom_css      .= '#stunning-section{ ' . Utouch_Helper_Html::attr_style( Utouch::template_stunning()->styles, false ) . '}';
        // Footer section styling.
        $footer_bg       = fw_get_db_customizer_option( 'footer_bg_color', '' );
        $footer_bg_img   = fw_get_db_customizer_option( 'footer_bg_image', '' );
        $footer_bg_cover = fw_get_db_customizer_option( 'footer_bg_cover', false );
        $footer_text     = fw_get_db_customizer_option( 'footer_text_color', '#9db5d4' );
        $footer_title    = fw_get_db_customizer_option( 'footer_title_color', '#ffffff' );

        if ( !empty( $footer_bg ) || !empty( $footer_bg_img ) || !empty( $footer_text ) ) {
            $custom_css .= '#site-footer .footer-wrapper{';
            if ( !empty( $footer_bg ) ) {
                $custom_css .= 'background-color:' . esc_attr( $footer_bg ) . ';';
            }
            if ( !empty( $footer_bg_img ) ) {
                $bg_img_url = utouch_akg( 'data/css/background-image', $footer_bg_img, '' );
                if ( isset( $footer_bg_img ) && !empty( $footer_bg_img ) ) {
                    $custom_css .= 'background-image:' . ( $bg_img_url ) . ';';

                    if ( true === $footer_bg_cover ) {
                        $custom_css .= 'background-size:cover;';
                    }
                }
            }
            if ( !empty( $footer_text ) ) {
                $custom_css .= 'color:' . esc_attr( $footer_text ) . ';';
            }
            $custom_css .= '}';
        }
        if ( !empty( $footer_title ) ) {
            $custom_css .= '#site-footer .widget .widget-title,#site-footer a:not(.btn), #site-footer .social__item svg, #site-footer .w-list ul.list, #site-footer .widget_nav_menu ul.list{';
            $custom_css .= 'color:' . esc_attr( $footer_title ) . ';';
            $custom_css .= 'fill:' . esc_attr( $footer_title ) . ';';
            $custom_css .= '}';
        }

        // Copyright section styling.
        $copyright_bg   = fw_get_db_customizer_option( 'copyright_bg_color', '' );
        $copyright_text = fw_get_db_customizer_option( 'copyright_text_color', '' );
        if ( !empty( $copyright_bg ) || !empty( $copyright_text ) ) {
            if ( !empty( $copyright_bg ) ) {
                $custom_css .= '#site-footer .sub-footer{ background-color:' . esc_attr( $copyright_bg ) . '}';
            }
            if ( !empty( $copyright_text ) ) {
                $custom_css .= '#site-footer .site-copyright-text{ color:' . esc_attr( $copyright_text ) . '}';
            }
        }

        wp_add_inline_style( 'utouch-style', $custom_css );
    }
}
