//Global var
var CRUMINA = CRUMINA || {};

// Set a default value for scrolled.
CRUMINA.scrolled = 0;

// polyfill closest
// https://developer.mozilla.org/en-US/docs/Web/API/Element/closest#Polyfill
if ( ! Element.prototype.closest ) {
	Element.prototype.closest = function( s ) {
		var el = this;

		do {
			if ( el.matches( s ) ) {
				return el;
			}

			el = el.parentElement || el.parentNode;
		} while ( el !== null && el.nodeType === 1 );

		return null;
	};
}

// polyfill forEach
// https://developer.mozilla.org/en-US/docs/Web/API/NodeList/forEach#Polyfill
if ( window.NodeList && ! NodeList.prototype.forEach ) {
	NodeList.prototype.forEach = function( callback, thisArg ) {
		var i;
		var len = this.length;

		thisArg = thisArg || window;

		for ( i = 0; i < len; i++ ) {
			callback.call( thisArg, this[ i ], i, this );
		}
	};
}

// event "polyfill"
CRUMINA.createEvent = function( eventName ) {
	var event;
	if ( typeof window.Event === 'function' ) {
		event = new Event( eventName );
	} else {
		event = document.createEvent( 'Event' );
		event.initEvent( eventName, true, false );
	}
	return event;
};

// matches "polyfill"
// https://developer.mozilla.org/es/docs/Web/API/Element/matches
if ( ! Element.prototype.matches ) {
	Element.prototype.matches =
		Element.prototype.matchesSelector ||
		Element.prototype.mozMatchesSelector ||
		Element.prototype.msMatchesSelector ||
		Element.prototype.oMatchesSelector ||
		Element.prototype.webkitMatchesSelector ||
		function( s ) {
			var matches = ( this.document || this.ownerDocument ).querySelectorAll( s ),
				i = matches.length;
			while ( --i >= 0 && matches.item( i ) !== this ) {}
			return i > -1;
		};
}


(function ($) {

    // USE STRICT
    "use strict";

    //----------------------------------------------------/
    // Predefined Variables
    //----------------------------------------------------/
    var $window = $(window),
        $document = $(document),
        $body = $('body'),
        swipers = {},

        //Elements
        $header = $('#site-header'),
        $header_space = $header.next('.header-spacer'),
        $preloader = $('#hellopreloader');

    /* -----------------------
	 * Header Spacer
	 * --------------------- */

    CRUMINA.headerSpacer = function () {
        setTimeout(function () {
            var $headerHeight = $header.outerHeight();

            $header_space.css('height', $headerHeight + 'px');
        }, 100);
    };


    /* -----------------------
     * Preloader
     * --------------------- */
    CRUMINA.preloader = function () {
        setTimeout(function () {
            $preloader.fadeOut(800);
        }, 500);
        return false;
    };


    CRUMINA.is_empty_attr = function (array_or_object, key) {
        return array_or_object[key] === undefined || array_or_object[key] == '';
    };


    /* -----------------------------
     * Sliders and Carousels
     * ---------------------------*/
    CRUMINA.initSwiper = function () {
        var initIterator = 0;

        $('.swiper-container').each(function () {

            var $t = $(this);
            var index = 'swiper-unique-id-' + initIterator;
            var $breakPoints = false;
            $t.addClass('swiper-' + index + ' initialized').attr('id', index);
            $t.closest('.crumina-module').find('.swiper-pagination').addClass('pagination-' + index);

            var $effect = ($t.data('effect')) ? $t.data('effect') : 'slide',
                $crossfade = ($t.data('crossfade')) ? $t.data('crossfade') : true,
                $loop = ($t.data('loop') == false) ? $t.data('loop') : true,
                $showItems = ($t.data('show-items')) ? $t.data('show-items') : 1,
                $scrollItems = ($t.data('scroll-items')) ? $t.data('scroll-items') : 1,
                $scrollDirection = ($t.data('direction')) ? $t.data('direction') : 'horizontal',
                $mouseScroll = ($t.data('mouse-scroll')) ? $t.data('mouse-scroll') : false,
                $autoplay = ($t.data('autoplay')) ? parseInt($t.data('autoplay'), 10) : 0,
                $autoheight = ($t.hasClass('auto-height')) ? true : false,
                $nospace = ($t.data('nospace')) ? $t.data('nospace') : false,
                $centeredSlider = ($t.data('centered-slider')) ? $t.data('centered-slider') : false,
                $stretch = ($t.data('stretch')) ? $t.data('stretch') : 0,
                $depth = ($t.data('depth')) ? $t.data('depth') : 0,
                $speed = ($t.data('speed')) ? $t.data('speed') : 300,
                $slidesSpace = ($showItems > 1 && true != $nospace) ? 20 : 0;

            var $slides_per_screen = {};

            if ($t.data('md-slides')) {
                $slides_per_screen['1024'] = {
                    slidesPerView: $t.data('md-slides'),
                    slidesPerGroup: $t.data('md-slides')
                };
            }

            if ($t.data('sm-slides')) {
                $slides_per_screen['768'] = {
                    slidesPerView: $t.data('sm-slides'),
                    slidesPerGroup: $t.data('sm-slides')
                };
            }


            if ($showItems > 1) {
                $breakPoints = {
                    480: {
                        slidesPerView: 1,
                        slidesPerGroup: 1
                    },
                    768: {
                        slidesPerView: 2,
                        slidesPerGroup: 2
                    }
                };

                if (Object.keys($slides_per_screen).length) {
                    $breakPoints = $slides_per_screen;
                }

            }

            var swiperParams = {
                pagination: '.pagination-' + index,
                paginationClickable: true,
                direction: $scrollDirection,
                mousewheelControl: $mouseScroll,
                mousewheelReleaseOnEdges: $mouseScroll,
                slidesPerView: $showItems,
                slidesPerGroup: $scrollItems,
                spaceBetween: $slidesSpace,
                keyboardControl: true,
                setWrapperSize: true,
                preloadImages: true,
                updateOnImagesReady: true,
                centeredSlides: $centeredSlider,
                autoplay: $autoplay,
                autoplayDisableOnInteraction: false,
                autoHeight: $autoheight,
                loop: $loop,
                breakpoints: $breakPoints,
                effect: $effect,
                fade: {
                    crossFade: $crossfade
                },
                speed: $speed,
                parallax: true,
                onImagesReady: function (swiper) {
                    CRUMINA.resizeSwiper(swiper);
                },
                onTransitionStart: function (swiper) {
                    CRUMINA.resizeSwiper(swiper);
                },
                onSlideChangeStart: function (swiper) {

                    var $slider_slides = $t.closest('.crumina-module-slider').find('.slider-slides');
                    if ($slider_slides.length) {
                        $slider_slides.find('.slide-active').removeClass('slide-active');
                        var activeIndex = 1;
                        if (1 === swiper.loopedSlides) {
                            activeIndex = swiper.activeIndex - 1;
                        } else {
                            activeIndex = swiper.activeIndex;
                        }
                        var $slides_item = $slider_slides.find('.slides-item');
                        activeIndex = activeIndex % $slides_item.size();
                        $slides_item.eq(activeIndex).addClass('slide-active');

                    }
                }
            };

            if ($stretch || $depth) {
                swiperParams['coverflow'] = {
                    stretch: $stretch,
                    rotate: 0,
                    depth: $depth,
                    modifier: 2,
                    slideShadows: false
                };
            }

            swipers['swiper-' + index] = new Swiper('.swiper-' + index, swiperParams);
            initIterator++;
        });

        //swiper arrows
        $('.btn-prev').on('click', function () {
            var current_id = $(this).closest('.crumina-module-slider').find('.swiper-container').attr('id');
            swipers['swiper-' + current_id].slidePrev();
        });

        $('.btn-next').on('click', function () {
            var current_id = $(this).closest('.crumina-module-slider').find('.swiper-container').attr('id');
            swipers['swiper-' + current_id].slideNext();
        });

        //swiper tabs

        $('.slider-slides .slides-item').on('click', function (e) {
            e.preventDefault();
            var current_id = $(this).closest('.crumina-module-slider').find('.swiper-container').attr('id');
            var mySwiper = swipers['swiper-' + current_id];
            if ($(this).hasClass('slide-active'))
                return false;
            var activeIndex = $(this).parent().find('.slides-item').index(this);
            var $loop = (mySwiper.container.data('loop') === false) ? mySwiper.container.data('loop') : true;
            if (true === $loop) {
                activeIndex = activeIndex + 1;
            }
            mySwiper.slideTo(activeIndex);
            $(this).parent().find('.slide-active').removeClass('slide-active');
            $(this).addClass('slide-active');
            mySwiper.update();
            return false;
        });
    };
    CRUMINA.resizeSwiper = function (swiper) {
        swiper = (swiper) ? swiper : $(this)[0].swiper;

        var activeSlideHeight = swiper.slides.eq(swiper.activeIndex).find('> *').outerHeight();

        if ($(swiper.container).hasClass('pagination-vertical')) {
            var headlineHeights = swiper.slides.map(function () {
                return $(this).find('> *').height();
            }).get();

            var maxHeadLineHeight = Math.max.apply(Math, headlineHeights);
            swiper.container.css({height: maxHeadLineHeight + 'px'});
            swiper.update(true)
        }

        if ($(swiper.container).hasClass('auto-height')) {
            swiper = (swiper) ? swiper : $(this)[0].swiper;
            swiper.container.css({height: activeSlideHeight + 'px'});
            swiper.onResize();
        }

        $('.swiper-container.js-full-window').each(function () {
            var $slider = $(this);
            var winHei = $(window).height();
            $slider.css('min-height', winHei + 'px');
            if ($header_space.length) {
                var $heder_height = $header_space.height();
            } else {
                $heder_height = 0;
            }
            $slider.css('min-height', winHei - $heder_height + 'px');
            $slider.find('> .swiper-wrapper').css('min-height', winHei - $heder_height + 'px');
        });
    };


    CRUMINA.initSmoothScroll = {
        selector: 'current-menu-item',
        $menu: null,
        $header: null,
        $anchors: null,
        $menuAnchors: null,
        $menuCurrents: null,
        init: function () {
            this.$menu = $('#primary-menu');
            this.$header = $('#site-header');

            this.$menuCurrents = jQuery('.' + this.selector + ' > a', this.$menu);

            this.$menuAnchors = jQuery('a', this.$menu).filter(function () {
                var url = this;

                return url.hash ? true : false;
            });

            this.$anchors = jQuery('a.btn').filter(function () {
                var url = this;

                return url.hash ? true : false;
            }).add(this.$menuAnchors);

            this.$anchors.attr('data-scroll', true);

            this.addEventListeners();

            this.deleteCurrentClass();

            this.scroolToInitial();

        },
        deleteCurrentClass: function () {
            var _this = this;
            this.$menuCurrents.each(function () {
                var $self = jQuery(this);
                if (this.hash) {
                    $self.parent().removeClass(_this.selector);
                }
            });
        },
        addEventListeners: function () {
            var _this = this;
            var scrollParams = {
                selector: '[data-scroll]',
                speed: 500,
                easing: 'easeOutQuad',
                updateURL: true,
                callback: function (anchor, toggle) {
                    _this.toggleAnchors();
                }
            };

            if (this.$header.length) {
                scrollParams['offset'] = $header.height();
            }

            smoothScroll.init(scrollParams);
        },
        toggleAnchors: function () {
            var _this = this;
            var current = location.origin + location.pathname;
            var hash = location.hash;

            this.$menuAnchors.each(function () {
                var self = this;
                var $self = jQuery(this);
                var $parent = $self.parent('li');
                var url = self.origin + self.pathname;
                var anchor = self.hash;

                $parent.removeClass('current-menu-item');

                if (current === url && hash && hash === anchor) {
                    _this.$menuCurrents.parent().removeClass('current-menu-item');

                    $parent.addClass('current-menu-item');
                }
            });
        },
        scroolToInitial: function () {
            var hash = location.hash.replace(/[#\s]/gim, '');

            if (!hash) {
                return;
            }

            var $anchor = jQuery('#' + hash);

            if (!$anchor.length) {
                return;
            }

            smoothScroll.animateScroll($anchor[0]);
        }
    };


    /* -----------------------------
     * On Click Functions
     * ---------------------------*/
    $window.keydown(function (eventObject) {
        if (eventObject.which == 27) {
            $body.removeClass('overlay-enable');
            $('#menu-icon-trigger').css({'opacity': '1'});
            $('.top-bar').removeClass('open');
        }
    });

    $(".overlay_search-close").on('click', function (e) {
        e.preventDefault();
        $body.removeClass('open');
        return false;
    });

    $('#top-bar-js').on('click', function (e) {
        e.preventDefault();
        $('.top-bar').addClass('open');
        return false;
    });

    $("#top-bar-close-js").on('click', function (e) {
        e.preventDefault();
        $('.top-bar').removeClass('open');
        return false;
    });

    $(".js-message-popup").on('click', function (e) {
        e.preventDefault();
        $('.message-popup').toggleClass('open');
        return false;
    });

    /* -----------------------------
     * Toggle search overlay
     * ---------------------------*/
    CRUMINA.toggleSearch = function () {
        $('.search-popup').toggleClass('open');
        $('.search-popup .js-popup-close').focus();
    };

    $(".js-open-search-popup").on('click', function (e) {
        e.preventDefault();
        CRUMINA.toggleSearch();
        return false;
    });

    $(".js-popup-close").on('click', function (e) {
        e.preventDefault();
        $('.search-popup').removeClass('open');
        $('.message-popup').removeClass('open');
        $('.popup-gallery').removeClass('open');
        $('.js-open-search-popup').focus();
        return false;
    });

    $(".js-popup-clear-input").on('click', function () {
        $(".js-popup-clear-input").siblings("input").val("").focus();
    });

    //Scroll to top.
    $('.back-to-top').on('click', function () {
        $('html,body').animate({
            scrollTop: 0
        }, 1200);
        return false;
    });
    /*
     * Replace all SVG images with inline SVG
     */
    CRUMINA.setSvgInline = function () {

        $('span.svg-replace').each(function () {
            var $img = $(this);
            var imgID = $img.attr('id');
            var imgClass = $img.attr('class');
            var imgURL = $img.data('src');

            jQuery.get(imgURL, function (data) {
                // Get the SVG tag, ignore the rest
                var $svg = jQuery(data).find('svg');

                // Add replaced image's ID to the new SVG
                if (typeof imgID !== 'undefined') {
                    $svg = $svg.attr('id', imgID);
                }
                // Add replaced image's classes to the new SVG
                if (typeof imgClass !== 'undefined') {
                    $svg = $svg.attr('class', imgClass + ' replaced-svg');
                }

                // Remove any invalid XML tags as per http://validator.w3.org
                $svg = $svg.removeAttr('xmlns:a');

                // Replace image with new SVG
                $img.replaceWith($svg);

            }, 'xml');

        });
    };


	// Fix sub-menus for touch devices and better focus for hidden submenu items for accessibility.
	CRUMINA.primaryMenu = {

		init: function() {
			this.focusMenuWithChildren();
		},

		// The focusMenuWithChildren() function implements Keyboard Navigation in the Primary Menu
		// by adding the '.focus' class to all 'li.menu-item-has-children' when the focus is on the 'a' element.
		focusMenuWithChildren: function() {
			// Get all the link elements within the primary menu.
			var links, i, len,
				menu = document.querySelector( '.utouch-header-menu-wrapper' );

			if ( ! menu ) {
				return false;
			}

			links = menu.getElementsByTagName( 'a' );

			// Each time a menu link is focused or blurred, toggle focus.
			for ( i = 0, len = links.length; i < len; i++ ) {
				links[i].addEventListener( 'focus', toggleFocus, true );
				links[i].addEventListener( 'blur', toggleFocus, true );
			}

			//Sets or removes the .focus class on an element.
			function toggleFocus() {
				var self = this;

				// Move up through the ancestors of the current link until we hit .utouch-header-menu
				while ( -1 === self.className.indexOf( 'utouch-header-menu' ) ) {
					// On li elements toggle the class .focus.
					if ( 'li' === self.tagName.toLowerCase() ) {
						if ( -1 !== self.className.indexOf( 'focus' ) ) {
							self.className = self.className.replace( ' focus', '' );
						} else {
							self.className += ' focus';
						}
					}
					self = self.parentElement;
				}
			}
		}
	};

	CRUMINA.fixTabindexMobileMenu = function (){
		var menuItems = document.querySelectorAll('.header-menu--mobile > li > a');
		var lastItem = menuItems[menuItems.length - 1];
		lastItem.setAttribute('x-ref', 'menuLastItem');
	};

	// Fix the submenu on the right side
	CRUMINA.fixMainMenu = function (){
		const mobileWidthBase = 768;
		var submenus = document.querySelectorAll(".utouch-header-menu li ul");
		var windowWidth = window.innerWidth;

		if(windowWidth > mobileWidthBase){
			var menu_width = window.innerWidth;
			for(var i = 0; i < submenus.length; i++){
				var submenusPositionStyle = submenus[i].setAttribute("style", "display:block;");

				function getCoords() {
					var box = submenus[i].getBoundingClientRect();
					return {
						left: box.left + pageXOffset
					}
				}
				var submenusPosition = getCoords().left;

				if(submenus[i].offsetWidth + submenusPosition > menu_width){
					submenus[i].classList.add("sub-menu-left");
				}else{
					if(menu_width == submenus[i].offsetWidth || (menu_width - submenus[i].offsetWidth) < 20){
						submenus[i].classList.add("sub-menu-left");
					}
					if(submenusPosition + submenus[i].offsetWidth < menu_width){
						submenus[i].classList.add("sub-menu-right");
					}
				}
			}
		}
	};

    /* -----------------------------
     * On DOM ready functions
     * ---------------------------*/
    $document.ready(function () {

        $("#top-bar-language").on('change', function () {
            var lang_href = $($(this).children('[value=' + $(this).val() + ']')).data('url');
            if (lang_href) {
                document.location.href = lang_href;
            }
        });

        CRUMINA.cartPopup = {
            $wrap: null,
            $cart: null,
            init: function () {
                this.$wrap = $('.nav-add .cart-contents');
                this.$cart = $('.cart-popup-wrap', this.$wrap);

                this.addEventListeners();
            },
            addEventListeners: function () {
                var _this = this;
                this.$wrap.on('click', '.js-cart-animate', function (event) {
                    event.preventDefault();
                    _this.$cart.toggleClass('visible');
                    _this.$cart.fadeToggle(200);
                });

                $document.on('click', function (event) {
                    if (!$(event.target).closest(_this.$wrap).length) {
                        if (_this.$cart.hasClass('visible')) {
                            _this.$cart.fadeToggle(200);
                            _this.$cart.toggleClass('visible')
                        }
                    }
                });
            }
        };

        CRUMINA.setSvgInline();
        CRUMINA.initSwiper();
        CRUMINA.initSmoothScroll.init();
        CRUMINA.cartPopup.init();
        CRUMINA.headerSpacer();
		CRUMINA.primaryMenu.init();
		CRUMINA.fixMainMenu();
		CRUMINA.fixTabindexMobileMenu();

        if ($preloader.length) {
            CRUMINA.preloader();
        }
        // Dom mofifications
        $('.nice-select').niceSelect();

        $(window).on('resize', function () {
            CRUMINA.headerSpacer();
        });
    });
})(jQuery);