<?php
/**
 * Template part for displaying popup with contact form.
 *
 * @package Utouch
 */


$utouch_contact_email = Utouch::get_var( 'widget_contact_email' );
$utouch_contact_form  = Utouch::get_var( 'widget_contact_shortcode' );
$utouch_form_type = 'default';
$utouch_contact_title = esc_html__( 'Send a Message', 'utouch-lite' );
$utouch_contact_description = '';
$utouch_contact_text_btn = esc_html__('Send a Message','utouch-lite');
$utouch_contact_color_btn = 'green';
$utouch_contact_thanks = esc_html__('Message sent!','utouch-lite');

if ( ! empty( $utouch_contact_form ) && function_exists( 'fw_set_db_customizer_option' ) ) {
	fw_set_db_customizer_option( 'contact_form/type', 'shortcode' );
}

if ( function_exists( 'fw_get_db_customizer_option' ) ) {
	$utouch_options   = fw_get_db_customizer_option( 'contact_form' );
	$utouch_form_type = utouch_akg( 'type', $utouch_options, 'default' );
	if ( empty( $utouch_contact_form ) ) {
		$utouch_contact_form = utouch_akg( 'shortcode/shortcode', $utouch_options, '' );
	}
	$utouch_form_id = utouch_akg('custom/form_id', $utouch_options, '');
	$utouch_color_btn = utouch_akg('custom/color_btn', $utouch_options, 'primary');

	/* Default contact form options */

	$utouch_contact_email = utouch_akg( 'default/email', $utouch_options, $utouch_contact_email );
	$utouch_contact_title = utouch_akg( 'default/title', $utouch_options, $utouch_contact_title );
	$utouch_contact_description = utouch_akg( 'default/description', $utouch_options, $utouch_contact_description );
	$utouch_contact_text_btn = utouch_akg('default/text_btn', $utouch_options, $utouch_contact_text_btn);
	$utouch_contact_color_btn = utouch_akg('default/color_btn', $utouch_options, $utouch_contact_color_btn);
	$utouch_contact_thanks = utouch_akg('default/thanks',$utouch_options,$utouch_contact_thanks);
	if ( empty( $utouch_contact_color_btn ) ) {
		$utouch_contact_color_btn = 'primary';
	}
} ?>
    <div class="window-popup message-popup">
        <a href="#" class="popup-close js-popup-close cd-nav-trigger">
            <svg class="utouch-icon utouch-icon-cancel-1">
                <use xlink:href="#utouch-icon-cancel-1"></use>
            </svg>
        </a>

        <div class="send-message-popup">
            <?php if ( 'shortcode' === $utouch_form_type && ! empty( $utouch_contact_form ) ) {
	            echo do_shortcode( $utouch_contact_form );
            } elseif ( 'custom' === $utouch_form_type && ! empty( $utouch_form_id ) ) {
	            Utouch_Helper_Html::generate_crumina_form( $utouch_form_id, $utouch_color_btn );
            } else {
	            $utouch_ajax_nonce = wp_create_nonce( 'widget_contact_form' );
               ?>

                <form class="contact-form" method="post"
                      action="<?php echo esc_url( home_url() . '?action=widget_contact_form' ) ?>"
                      data-thanks="<?php echo esc_attr( $utouch_contact_thanks ) ?>">

                    <?php  if ( ! empty( $utouch_contact_title ) ) {
	                    echo utouch_html_tag( 'h5', array(), esc_html( $utouch_contact_title ) );
                    }
                    if ( ! empty( $utouch_contact_description ) ) {
	                    echo utouch_html_tag( 'p', array(), esc_html( $utouch_contact_description ) );
                    } ?>

                    <input name="mail_to" type="hidden" value="<?php echo esc_attr( $utouch_contact_email ) ?>">
                    <input type="hidden" name="security" value="<?php echo esc_attr($utouch_ajax_nonce); ?>">
                    <div class="with-icon">
                        <input name="name" placeholder="<?php echo esc_attr__( 'Your Name', 'utouch-lite' ) ?>" type="text"
                               required="required">
                        <svg class="utouch-icon utouch-icon-user">
                            <use xlink:href="#utouch-icon-user"></use>
                        </svg>
                    </div>
                    <div class="with-icon">
                        <input name="email" placeholder="<?php echo esc_attr__( 'Email Adress', 'utouch-lite' ) ?>"
                               type="text" required="required">
                        <svg class="utouch-icon utouch-icon-message-closed-envelope-1">
                            <use xlink:href="#utouch-icon-message-closed-envelope-1"></use>
                        </svg>
                    </div>

                    <div class="with-icon">
                        <input class="with-icon" name="phone"
                               placeholder="<?php echo esc_attr__( 'Phone Number', 'utouch-lite' ) ?>" type="tel"
                               required="required">
                        <svg class="utouch-icon utouch-icon-telephone-keypad-with-ten-keys">
                            <use xlink:href="#utouch-icon-telephone-keypad-with-ten-keys"></use>
                        </svg>
                    </div>

                    <div class="with-icon">
                        <input class="with-icon" name="subject"
                               placeholder="<?php echo esc_attr__( 'Subject', 'utouch-lite' ) ?>" type="text"
                               required="required">
                        <svg class="utouch-icon utouch-icon-icon-1">
                            <use xlink:href="#utouch-icon-icon-1"></use>
                        </svg>
                    </div>

                    <div class="with-icon">
                        <textarea name="message" required
                                  placeholder="<?php echo esc_attr__( 'Your Message', 'utouch-lite' ) ?>"
                                  style="min-height: 180px;"></textarea>
                        <svg class="utouch-icon utouch-icon-edit">
                            <use xlink:href="#utouch-icon-edit"></use>
                        </svg>
                    </div>

                    <button class="btn btn--<?php echo esc_attr( $utouch_contact_color_btn ) ?> btn--with-shadow full-width" >
		                <?php echo esc_html( $utouch_contact_text_btn ) ?>
                    </button>
                </form>
            <?php } ?>
        </div>
    </div>